function pfss_time2file, time0, time1, urls=urls, debug=debug, $
   before=before, after=after, count=count, refresh=refresh, $
   ssw_catalog=ssw_catalog, generate=generate, loud=loud
;+
;   Name: pfss_time2file
;
;   Purpose: any ssw time -> PFSS save file (MDI extrap); NFS or URL
;
;   Input Parameters:
;      time0 - time desired, any SSW format (string, index record..)
;      time1 - optional stop time for range
;
;   Output:
;      function returns files or urls matching users input time/range
;
;   Keyword Parameters:
;      URLS - if set, return URLs 
;      BEFORE - if set, match closest BEFORE (default is closest)
;      AFTER - if set, match closest AFTER   (default is closest)
;      COUNT (output) - number of files returned (zero implies error)
;      SSW_CATALOG - if set, use $SSWDB/pfss/catalog 
;      GENERATE - if set (and permission and local), generate SSWDB cat
;
;   Calling Sequence:
;      mdisav=pfss_time2file(time [,/BEFORE] [,/AFTER] )   
;      mdisavs=pfss_time2file(startT, endT, [,/BEFORE] [,/AFTER] )
;
;   5-December-2003 - S.L.Freeland - ssw/pfss integration helper
;-

common pfss_time2file_blk, times, links

debug=keyword_set(debug)
urls=keyword_set(urls)

count=0
retval=''
refresh=keyword_set(refresh)
before=keyword_set(before)
after=keyword_set(after)
loud=keyword_set(loud)

authorize=str2arr('freeland,derosa,hurlburt')
generate=keyword_set(generate) and is_member(get_user(),authorize)

ssw_catalog=keyword_set(ssw_catalog) or generate

pfss_path=get_logenv('PFSS_PATH')
pfss_http=get_logenv('PFSS_HTTP')
date_sub='Bfield-bydate'

if pfss_path eq '' then $
   pfss_path='/hosts/solserv/data1/pfss/kitrun48'

if pfss_http eq '' then $
   pfss_http='http://www.lmsal.com/solarsoft/pfss'

pfsscatdir=$
   concat_dir(concat_dir(concat_dir('$SSWDB','packages'),'pfss'),'genxcat')

bfieldcat=concat_dir(pfsscatdir,'bfield.geny')

if ssw_catalog and file_exist(bfieldcat) then $
   restgenx, file=bfieldcat, times, links

refresh=file_exist(pfss_path) and $
   n_elements(links) eq 0 or keyword_set(refresh) or generate

if refresh then begin 
   box_message,'Initializing file list'
   files=findfile(concat_dir(pfss_path,date_sub))
   ss=where(strpos(files,'Bfield') ne -1 and $
            strpos(files,'.sav')   ne -1, fcnt)
   if fcnt eq 0 then begin 
      box_message,'Problem with PFSS listing, bailing out..
      stop
      return,''
   endif
   links=files(ss)
   times=strextract(links,'Bfield_','.sav')    ; CCSDS filename
   times=anytim(temporary(times),/TAI)         ; ->TAI
   if generate then begin
      savegenx, times, links, file=bfieldcat  
   endif
endif

case n_params() of 
   1: begin
         t0=anytim(time0,/TAI)
         t1=t0         
   endcase
   2: begin
         t0=anytim(time0,/TAI)
         t1=anytim(time1,/TAI)
   endcase
   else: begin
      t0=times(0)
      t1=last_nelem(times)
   endcase
endcase

dtimes=times-t0
if n_params() eq 1 then begin 
   abdt=abs(dtimes)
   ss=(where(abdt eq min(abdt)))(0)
endif else begin 
   ss=where(times ge t0 and times le t1,count)
endelse

if ss(0) ne -1 then begin 
   retval=links(ss)
   count=n_elements(retval)
endif
 
if urls then begin
   retval=pfss_http + '/' + date_sub + '/' + temporary(retval) 
endif else begin 
   retval=concat_dir(concat_dir(pfss_path,date_sub),temporary(retval))
endelse
return, retval
end
  


